OverflowStrategy

Enum OverflowStrategy 

pub enum OverflowStrategy {
    DropNew,
    DropHead,
    DropTail,
    Fail,
}
What a bounded mailbox does when its capacity is reached. overflow policy.

Variants



DropNew

Drop the new (incoming) message and log it as a dead letter.



DropHead

Drop the oldest enqueued message and accept the new one.



DropTail

Drop the most-recently-enqueued message and accept the new one.



Fail

Reject the push and signal failure to the sender.