StashOverflow

Enum StashOverflow 

#[non_exhaustive]
pub enum StashOverflow { DropOldest, DropNewest, Reject, }
What to do when the stash is full and a new message arrives.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


DropOldest

Drop the oldest stashed message; queue the new one.



DropNewest

Drop the new message.



Reject

Drop the new message AND surface it to the caller as an error (so the runtime can route it to DeadLetters).